@@ -41,20 +41,6 @@ macro_rules! timing_trace {
 struct WrapEvtSender(futures::channel::mpsc::Sender<HolochainP2pEvent>);
 
 impl WrapEvtSender {
-    pub fn k_gen_req(
-        &self,
-        arg: KGenReq,
-    ) -> impl Future<Output = HolochainP2pResult<KGenRes>> + 'static + Send {
-        let dna_hash = match &arg {
-            KGenReq::PeerExtrapCov { space, .. } => DnaHash::from_kitsune(space),
-            KGenReq::RecordMetrics { space, .. } => DnaHash::from_kitsune(space),
-        };
-        timing_trace!(
-            { self.0.k_gen_req(dna_hash, arg) },
-            "(hp2p:handle) k_gen_req",
-        )
-    }
-
     pub fn put_agent_info_signed(
         &self,
         dna_hash: DnaHash,
@@ -66,22 +52,6 @@ impl WrapEvtSender {
         )
     }
 
-    fn get_agent_info_signed(
-        &self,
-        dna_hash: DnaHash,
-        to_agent: AgentPubKey,
-        kitsune_space: Arc<kitsune_p2p::KitsuneSpace>,
-        kitsune_agent: Arc<kitsune_p2p::KitsuneAgent>,
-    ) -> impl Future<Output = HolochainP2pResult<Option<AgentInfoSigned>>> + 'static + Send {
-        timing_trace!(
-            {
-                self.0
-                    .get_agent_info_signed(dna_hash, to_agent, kitsune_space, kitsune_agent)
-            },
-            "(hp2p:handle) get_agent_info_signed",
-        )
-    }
-
     fn query_gossip_agents(
         &self,
         dna_hash: DnaHash,
@@ -354,10 +324,11 @@ impl HolochainP2pActor {
         tls_config: kitsune_p2p::dependencies::kitsune_p2p_types::tls::TlsConfig,
         channel_factory: ghost_actor::actor_builder::GhostActorChannelFactory<Self>,
         evt_sender: futures::channel::mpsc::Sender<HolochainP2pEvent>,
+        host: kitsune_p2p::HostApi,
     ) -> HolochainP2pResult<Self> {
         let tuning_params = config.tuning_params.clone();
         let (kitsune_p2p, kitsune_p2p_events) =
-            kitsune_p2p::spawn_kitsune_p2p(config, tls_config).await?;
+            kitsune_p2p::spawn_kitsune_p2p(config, tls_config, host).await?;
 
         channel_factory.attach_receiver(kitsune_p2p_events).await?;
 
@@ -573,16 +544,6 @@ impl HolochainP2pActor {
 impl ghost_actor::GhostHandler<kitsune_p2p::event::KitsuneP2pEvent> for HolochainP2pActor {}
 
 impl kitsune_p2p::event::KitsuneP2pEventHandler for HolochainP2pActor {
-    fn handle_k_gen_req(
-        &mut self,
-        arg: KGenReq,
-    ) -> kitsune_p2p::event::KitsuneP2pEventHandlerResult<KGenRes> {
-        let evt_sender = self.evt_sender.clone();
-        Ok(async move { Ok(evt_sender.k_gen_req(arg).await?) }
-            .boxed()
-            .into())
-    }
-
     /// We need to store signed agent info.
     #[tracing::instrument(skip(self), level = "trace")]
     fn handle_put_agent_info_signed(
@@ -599,25 +560,6 @@ impl kitsune_p2p::event::KitsuneP2pEventHandler for HolochainP2pActor {
         )
     }
 
-    /// We need to get previously stored agent info.
-    #[tracing::instrument(skip(self), level = "trace")]
-    fn handle_get_agent_info_signed(
-        &mut self,
-        input: kitsune_p2p::event::GetAgentInfoSignedEvt,
-    ) -> kitsune_p2p::event::KitsuneP2pEventHandlerResult<Option<AgentInfoSigned>> {
-        let kitsune_p2p::event::GetAgentInfoSignedEvt { space, agent } = input;
-        let h_space = DnaHash::from_kitsune(&space);
-        let h_agent = AgentPubKey::from_kitsune(&agent);
-        let evt_sender = self.evt_sender.clone();
-        Ok(async move {
-            Ok(evt_sender
-                .get_agent_info_signed(h_space, h_agent, space, agent)
-                .await?)
-        }
-        .boxed()
-        .into())
-    }
-
     /// We need to get previously stored agent info. A single kitusne agent query
     /// can take one of three Holochain agent query paths. We do "duck typing"
     /// on the query object to determine which query path to take. The reason for
